==> nextcloud-26.0.11p1.tgz: nextcloud/apps/weather_status/l10n/fa.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unknown address",
    "No result." : "بدون نتیجه.",
    "Malformed JSON data." : "Malformed JSON data.",
    "Error" : "خطا",
    "Weather status" : "Weather status",
    "Weather status in your dashboard" : "Weather status in your dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app.",
    "Detect location" : "Detect location",
    "Set custom address" : "Set custom address",
    "Favorites" : "مورد علاقه ها",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} clear sky later today",
    "{temperature} {unit} clear sky" : "{temperature} {unit} clear sky",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} cloudy later today",
    "{temperature} {unit} cloudy" : "{temperature} {unit} cloudy",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} fair weather later today",
    "{temperature} {unit} fair weather" : "{temperature} {unit} fair weather",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} partly cloudy later today",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} partly cloudy",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} foggy later today",
    "{temperature} {unit} foggy" : "{temperature} {unit} foggy",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} light rainfall later today",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} light rainfall",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} rainfall later today",
    "{temperature} {unit} rainfall" : "{temperature} {unit} rainfall",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} heavy rainfall later today",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} heavy rainfall",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} rainfall showers later today",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} rainfall showers",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} light rainfall showers later today",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} light rainfall showers",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} heavy rainfall showers later today",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} heavy rainfall showers",
    "More weather for {adr}" : "More weather for {adr}",
    "Loading weather" : "Loading weather",
    "Remove from favorites" : "حذف کردن از برگزیده ها",
    "Add as favorite" : "Add as favorite",
    "You are not logged in." : "You are not logged in.",
    "There was an error getting the weather status information." : "There was an error getting the weather status information.",
    "No weather information found" : "No weather information found",
    "Location not found" : "Location not found",
    "There was an error setting the location address." : "There was an error setting the location address.",
    "There was an error setting the location." : "There was an error setting the location.",
    "There was an error saving the mode." : "There was an error saving the mode.",
    "There was an error using personal address." : "There was an error using personal address.",
    "Set location for weather" : "تنظیم مکان برای آب و هوا"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/weather_status/l10n/fa.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Unknown address",
    "No result." : "بدون نتیجه.",
    "Malformed JSON data." : "Malformed JSON data.",
    "Error" : "خطا",
    "Weather status" : "Weather status",
    "Weather status in your dashboard" : "Weather status in your dashboard",
    "Detect location" : "Detect location",
    "Set custom address" : "Set custom address",
    "Favorites" : "مورد علاقه ها",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} clear sky later today",
    "{temperature} {unit} clear sky" : "{temperature} {unit} clear sky",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} cloudy later today",
    "{temperature} {unit} cloudy" : "{temperature} {unit} cloudy",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} fair weather later today",
    "{temperature} {unit} fair weather" : "{temperature} {unit} fair weather",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} partly cloudy later today",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} partly cloudy",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} foggy later today",
    "{temperature} {unit} foggy" : "{temperature} {unit} foggy",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} light rainfall later today",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} light rainfall",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} rainfall later today",
    "{temperature} {unit} rainfall" : "{temperature} {unit} rainfall",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} heavy rainfall later today",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} heavy rainfall",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} rainfall showers later today",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} rainfall showers",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} light rainfall showers later today",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} light rainfall showers",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} heavy rainfall showers later today",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} heavy rainfall showers",
    "More weather for {adr}" : "More weather for {adr}",
    "Loading weather" : "Loading weather",
    "Remove from favorites" : "حذف کردن از برگزیده ها",
    "Add as favorite" : "Add as favorite",
    "You are not logged in." : "You are not logged in.",
    "There was an error getting the weather status information." : "There was an error getting the weather status information.",
    "No weather information found" : "No weather information found",
    "Location not found" : "Location not found",
    "There was an error setting the location address." : "There was an error setting the location address.",
    "There was an error setting the location." : "There was an error setting the location.",
    "There was an error saving the mode." : "There was an error saving the mode.",
    "There was an error using personal address." : "There was an error using personal address.",
    "Set location for weather" : "تنظیم مکان برای آب و هوا",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app."
},
"nplurals=2; plural=(n > 1);");
